@@ -12,9 +12,9 @@
 #    under the License.
 
 import re
+from unittest import mock
 
 import lxml.etree
-import mock
 import requests_mock
 
 import dracclient.client
@@ -346,10 +346,10 @@ class ClientBIOSConfigurationTestCase(base.BaseTest):
                 'SetAttributes']['ok'])
 
         result = self.drac_client.set_bios_settings(
-            {'ProcVirtualization': 'Disabled'})
+            {'ProcVirtualization': 'Disabled',
+             'DynamicCoreAllocation': 'Disabled'})
 
-        self.assertEqual({'commit_required': True,
-                          'is_commit_required': True,
+        self.assertEqual({'is_commit_required': True,
                           'is_reboot_required': constants.RebootRequired.true},
                          result)
         mock_invoke.assert_called_once_with(
@@ -399,8 +399,7 @@ class ClientBIOSConfigurationTestCase(base.BaseTest):
         result = self.drac_client.set_bios_settings(
             {'ProcVirtualization': 'Enabled'})
 
-        self.assertEqual({'commit_required': False,
-                          'is_commit_required': False,
+        self.assertEqual({'is_commit_required': False,
                           'is_reboot_required':
                           constants.RebootRequired.false},
                          result)
